# Security Policy

## Supported Versions

Versions which are currently being supported with security updates:

| Version | Supported          |
| ------- | ------------------ |
| > 0.2   | :white_check_mark: |

## Reporting a Vulnerability

To report a vulnerability, please create a new [*issue*](https://github.com/DerwenAI/kglab/issues).
We will be notified immediately, and will attempt to respond on the reported issue immediately.
